@@ -802,6 +802,9 @@ class NoHookRQLObjectStore(RQLObjectStore):
         assert not rtype.startswith('reverse_')
         self.add_relation(self.session, eid_from, rtype, eid_to,
                           self.rschema(rtype).inlined)
+        if self.rschema[rtype].symmetric:
+            self.add_relation(self.session, eid_to, rtype, eid_from,
+                              self.rschema(rtype).inlined)
         self._nb_inserted_relations += 1
 
     @property
@@ -928,6 +931,9 @@ class SQLGenObjectStore(NoHookRQLObjectStore):
         # XXX Could subjtype be inferred ?
         self.source.add_relation(self.session, subj_eid, rtype, obj_eid,
                                  self.rschema(rtype).inlined, **kwargs)
+        if self.rschema[rtype].symmetric:
+            self.source.add_relation(self.session, obj_eid, rtype, subj_eid,
+                                     self.rschema(rtype).inlined, **kwargs)
 
     def drop_indexes(self, etype):
         """Drop indexes for a given entity type"""
@@ -1058,7 +1064,7 @@ class SQLGenSourceWrapper(object):
             if subjtype is None:
                 # Try to infer it
                 targets = [t.type for t in
-                           self.schema.rschema(rtype).subjects()]
+                           self.schema.rschema(rtype).targets()]
                 if len(targets) == 1:
                     subjtype = targets[0]
                 else:
@@ -1110,9 +1116,9 @@ class SQLGenSourceWrapper(object):
     def _handle_source_relation_sql(self, session, sql, attrs):
         self._append_to_entities(sql, attrs)
 
-    # add_info is _copypasted_ from the one in NativeSQLSource. We want it
-    # there because it will use the _handlers of the SQLGenSourceWrapper, which
-    # are not like the ones in the native source.
+    # XXX add_info is similar to the one in NativeSQLSource. It is rewritten
+    # here to correctly used the _handle_xxx of the SQLGenSourceWrapper. This
+    # part should be rewritten in a more clearly way.
     def add_info(self, session, entity, source, extid, complete):
         """add type and source info for an eid into the system table"""
         # begin by inserting eid/type/source/extid into the entities table
