@@ -1,4 +1,4 @@
-# copyright 2003-2014 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of CubicWeb.
@@ -85,33 +85,11 @@ class JsonValidator(object):
     def parse_string(self, data):
         return json.loads(data)
 
-@contextmanager
-def real_error_handling(app):
-    """By default, CubicWebTC `app` attribute (ie the publisher) is monkey
-    patched so that unexpected error are raised rather than going through the
-    `error_handler` method.
-
-    By using this context manager you disable this monkey-patching temporarily.
-    Hence when publishihng a request no error will be raised, you'll get
-    req.status_out set to an HTTP error status code and the generated page will
-    usually hold a traceback as HTML.
-
-    >>> with real_error_handling(app):
-    >>>     page = app.handle_request(req)
-    """
-    # remove the monkey patched error handler
-    fake_error_handler = app.error_handler
-    del app.error_handler
-    # return the app
-    yield app
-    # restore
-    app.error_handler = fake_error_handler
-
 # email handling, to test emails sent by an application ########################
 
 MAILBOX = []
 
-class Email:
+class Email(object):
     """you'll get instances of Email into MAILBOX during tests that trigger
     some notification.
 
@@ -120,7 +98,8 @@ class Email:
     * `recipients` is a list of email address which are the recipients of this
       message
     """
-    def __init__(self, recipients, msg):
+    def __init__(self, fromaddr, recipients, msg):
+        self.fromaddr = fromaddr
         self.recipients = recipients
         self.msg = msg
 
@@ -147,8 +126,8 @@ class MockSMTP:
         pass
     def close(self):
         pass
-    def sendmail(self, helo_addr, recipients, msg):
-        MAILBOX.append(Email(recipients, msg))
+    def sendmail(self, fromaddr, recipients, msg):
+        MAILBOX.append(Email(fromaddr, recipients, msg))
 
 cwconfig.SMTP = MockSMTP
 
@@ -441,13 +420,10 @@ class CubicWebTC(TestCase):
         return self.cnx.cursor(req or self.request())
 
     @nocoverage
-    def execute(self, rql, args=None, eidkey=None, req=None):
+    def execute(self, rql, args=None, req=None):
         """executes <rql>, builds a resultset, and returns a couple (rset, req)
         where req is a FakeRequest
         """
-        if eidkey is not None:
-            warn('[3.8] eidkey is deprecated, you can safely remove this argument',
-                 DeprecationWarning, stacklevel=2)
         req = req or self.request(rql=rql)
         return req.execute(unicode(rql), args)
 
@@ -469,10 +445,7 @@ class CubicWebTC(TestCase):
 
     # server side db api #######################################################
 
-    def sexecute(self, rql, args=None, eid_key=None):
-        if eid_key is not None:
-            warn('[3.8] eid_key is deprecated, you can safely remove this argument',
-                 DeprecationWarning, stacklevel=2)
+    def sexecute(self, rql, args=None):
         self.session.set_cnxset()
         return self.session.execute(rql, args)
 
@@ -547,9 +520,9 @@ class CubicWebTC(TestCase):
         it2 = set(getattr(x, 'eid', x) for x in it2)
         super(CubicWebTC, self).assertItemsEqual(it1, it2, *args, **kwargs)
 
-    def assertMessageEqual(self, req, params, expected_msg):
+    def assertMessageEqual(self, req, params, msg):
         msg = req.session.data[params['_cwmsgid']]
-        self.assertEqual(expected_msg, msg)
+        self.assertEqual(msg, msg)
 
     # workflow utilities #######################################################
 
@@ -729,14 +702,17 @@ class CubicWebTC(TestCase):
         return self.ctrl_publish(req, ctrlid, rset)
 
     def http_publish(self, url, data=None):
-        """like `url_publish`, except this returns a http response, even in case
-        of errors. You may give form parameters using the `data` argument.
-        """
+        """like `url_publish`, except this returns a http response, even in case of errors"""
         req = self.req_from_url(url)
         if data is not None:
             req.form.update(data)
-        with real_error_handling(self.app):
+        # remove the monkey patched error handler
+        fake_error_handler = self.app.error_handler
+        del self.app.error_handler
+        try:
             result = self.app_handle_request(req, req.relative_path(False))
+        finally:
+            self.app.error_handler = fake_error_handler
         return result, req
 
     @staticmethod
@@ -1005,15 +981,6 @@ class CubicWebTC(TestCase):
             self.assertEqual(len(MAILBOX), nb_msgs)
         return messages
 
-    # deprecated ###############################################################
-
-    @deprecated('[3.8] use self.execute(...).get_entity(0, 0)')
-    def entity(self, rql, args=None, eidkey=None, req=None):
-        if eidkey is not None:
-            warn('[3.8] eidkey is deprecated, you can safely remove this argument',
-                 DeprecationWarning, stacklevel=2)
-        return self.execute(rql, args, req=req).get_entity(0, 0)
-
 
 # auto-populating test classes and utilities ###################################
 
