@@ -1082,7 +1082,7 @@ class Session(RequestSessionBase):
     def keep_cnxset_mode(self, mode):
         """set `mode`, e.g. how the session will keep its connections set:
 
-        * if mode == 'write', the connections set is freed after each ready
+        * if mode == 'write', the connections set is freed after each read
           query, but kept until the transaction's end (eg commit or rollback)
           when a write query is detected (eg INSERT/SET/DELETE queries)
 
@@ -1174,14 +1174,11 @@ class Session(RequestSessionBase):
     source_from_eid = tx_meth('source_from_eid')
 
 
-    def execute(self, rql, kwargs=None, eid_key=None, build_descr=True):
+    def execute(self, rql, kwargs=None, build_descr=True):
         """db-api like method directly linked to the querier execute method.
 
         See :meth:`cubicweb.dbapi.Cursor.execute` documentation.
         """
-        if eid_key is not None:
-            warn('[3.8] eid_key is deprecated, you can safely remove this argument',
-                 DeprecationWarning, stacklevel=2)
         self.timestamp = time() # update timestamp
         rset = self._execute(self, rql, kwargs, build_descr)
         rset.req = self
