@@ -757,27 +757,17 @@ class NativeSQLSource(SQLAdapterMixIn, AbstractSource):
             if ex.__class__.__name__ == 'IntegrityError':
                 # need string comparison because of various backends
                 for arg in ex.args:
-                    if 'SQL Server' in arg:
-                        mo = re.search("'unique_cw_[^ ]+'", arg)
-                    else: # postgres
-                        mo = re.search('"unique_cw_[^ ]+"', arg)
+                    # postgres, sqlserver
+                    mo = re.search("unique_[a-z0-9]{32}", arg)
                     if mo is not None:
-                        index_name = mo.group(0)[1:-1] # eat the surrounding " pair
-                        elements = index_name.split('_cw_')[1:]
-                        etype = elements[0]
-                        rtypes = elements[1:]
-                        raise UniqueTogetherError(etype, rtypes)
+                        raise UniqueTogetherError(session, cstrname=mo.group(0))
                     # sqlite
                     mo = re.search('columns (.*) are not unique', arg)
-                    if mo is None:
-                        # sqlite > 3.7
-                        mo = re.search('UNIQUE constraint failed: (.*)', arg)
                     if mo is not None: # sqlite in use
                         # we left chop the 'cw_' prefix of attribute names
                         rtypes = [c.strip()[3:]
                                   for c in mo.group(1).split(',')]
-                        etype = '???'
-                        raise UniqueTogetherError(etype, rtypes)
+                        raise UniqueTogetherError(session, rtypes=rtypes)
             raise
         return cursor
 
@@ -1709,8 +1699,6 @@ class DatabaseIndependentBackupRestore(object):
     Tables are saved in chunks in different files in order to prevent
     a too high memory consumption.
     """
-    blocksize = 100
-
     def __init__(self, source):
         """
         :param: source an instance of the system source
@@ -1795,7 +1783,10 @@ class DatabaseIndependentBackupRestore(object):
         sql = 'SELECT * FROM %s' % table
         columns, rows_iterator = self._get_cols_and_rows(sql)
         self.logger.info('number of rows: %d', rowcount)
-        blocksize = self.blocksize
+        if table.startswith('cw_'): # entities
+            blocksize = 2000
+        else: # relations and metadata
+            blocksize = 10000
         if rowcount > 0:
             for i, start in enumerate(xrange(0, rowcount, blocksize)):
                 rows = list(itertools.islice(rows_iterator, blocksize))
