@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# copyright 2003-2014 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2003-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
 #
 # This file is part of CubicWeb.
@@ -44,18 +44,6 @@ class EntityTC(CubicWebTC):
         for cls in self.vreg['etypes'].iter_classes():
             cls.fetch_attrs, cls.cw_fetch_order = self.backup_dict[cls]
 
-    def test_no_prefill_related_cache_bug(self):
-        session = self.session
-        usine = session.create_entity('Usine', lieu=u'Montbeliard')
-        produit = session.create_entity('Produit')
-        # usine was prefilled in glob_add_entity
-        # let's simulate produit creation without prefill
-        produit._cw_related_cache.clear()
-        # use add_relations
-        session.add_relations([('fabrique_par', [(produit.eid, usine.eid)])])
-        self.assertEqual(1, len(usine.reverse_fabrique_par))
-        self.assertEqual(1, len(produit.fabrique_par))
-
     def test_boolean_value(self):
         e = self.vreg['etypes'].etype_class('CWUser')(self.request())
         self.assertTrue(e)
@@ -145,6 +133,12 @@ class EntityTC(CubicWebTC):
         self.assertEqual(sorted(user._cw_related_cache), ['in_group_subject', 'primary_email_subject'])
         for group in groups:
             self.assertFalse('in_group_subject' in group._cw_related_cache, list(group._cw_related_cache))
+        user.cw_clear_all_caches()
+        user.related('in_group', entities=True)
+        self.assertIn('in_group_subject', user._cw_related_cache)
+        user.cw_clear_all_caches()
+        user.related('in_group', targettypes=('CWGroup',), entities=True)
+        self.assertNotIn('in_group_subject', user._cw_related_cache)
 
     def test_related_limit(self):
         req = self.request()
@@ -158,6 +152,18 @@ class EntityTC(CubicWebTC):
         self.assertEqual(len(p.related('tags', 'object', entities=True, limit=2)), 2)
         self.assertEqual(len(p.related('tags', 'object', entities=True)), 4)
 
+    def test_related_targettypes(self):
+        req = self.request()
+        p = req.create_entity('Personne', nom=u'Loxodonta', prenom=u'Babar')
+        n = req.create_entity('Note', type=u'scratch', ecrit_par=p)
+        t = req.create_entity('Tag', name=u'a tag', tags=(p, n))
+        self.commit()
+        req = self.request()
+        t = req.entity_from_eid(t.eid)
+        self.assertEqual(2, t.related('tags').rowcount)
+        self.assertEqual(1, t.related('tags', targettypes=('Personne',)).rowcount)
+        self.assertEqual(1, t.related('tags', targettypes=('Note',)).rowcount)
+
     def test_cw_instantiate_relation(self):
         req = self.request()
         p1 = req.create_entity('Personne', nom=u'di')
@@ -201,43 +207,43 @@ class EntityTC(CubicWebTC):
             # testing basic fetch_attrs attribute
             self.assertEqual(Personne.fetch_rql(user),
                               'Any X,AA,AB,AC ORDERBY AA '
-                              'WHERE X is Personne, X nom AA, X prenom AB, X modification_date AC')
+                              'WHERE X is_instance_of Personne, X nom AA, X prenom AB, X modification_date AC')
             # testing unknown attributes
             Personne.fetch_attrs = ('bloug', 'beep')
-            self.assertEqual(Personne.fetch_rql(user), 'Any X WHERE X is Personne')
+            self.assertEqual(Personne.fetch_rql(user), 'Any X WHERE X is_instance_of Personne')
             # testing one non final relation
             Personne.fetch_attrs = ('nom', 'prenom', 'travaille')
             self.assertEqual(Personne.fetch_rql(user),
                               'Any X,AA,AB,AC,AD ORDERBY AA '
-                              'WHERE X is Personne, X nom AA, X prenom AB, X travaille AC?, AC nom AD')
+                              'WHERE X is_instance_of Personne, X nom AA, X prenom AB, X travaille AC?, AC nom AD')
             # testing two non final relations
             Personne.fetch_attrs = ('nom', 'prenom', 'travaille', 'evaluee')
             self.assertEqual(Personne.fetch_rql(user),
                              'Any X,AA,AB,AC,AD,AE ORDERBY AA '
-                             'WHERE X is Personne, X nom AA, X prenom AB, X travaille AC?, AC nom AD, '
+                             'WHERE X is_instance_of Personne, X nom AA, X prenom AB, X travaille AC?, AC nom AD, '
                              'X evaluee AE?')
             # testing one non final relation with recursion
             Personne.fetch_attrs = ('nom', 'prenom', 'travaille')
             Societe.fetch_attrs = ('nom', 'evaluee')
             self.assertEqual(Personne.fetch_rql(user),
                               'Any X,AA,AB,AC,AD,AE,AF ORDERBY AA,AF DESC '
-                              'WHERE X is Personne, X nom AA, X prenom AB, X travaille AC?, AC nom AD, '
+                              'WHERE X is_instance_of Personne, X nom AA, X prenom AB, X travaille AC?, AC nom AD, '
                               'AC evaluee AE?, AE modification_date AF'
                               )
             # testing symmetric relation
             Personne.fetch_attrs = ('nom', 'connait')
             self.assertEqual(Personne.fetch_rql(user), 'Any X,AA,AB ORDERBY AA '
-                              'WHERE X is Personne, X nom AA, X connait AB?')
+                              'WHERE X is_instance_of Personne, X nom AA, X connait AB?')
             # testing optional relation
             peschema.subjrels['travaille'].rdef(peschema, seschema).cardinality = '?*'
             Personne.fetch_attrs = ('nom', 'prenom', 'travaille')
             Societe.fetch_attrs = ('nom',)
             self.assertEqual(Personne.fetch_rql(user),
-                              'Any X,AA,AB,AC,AD ORDERBY AA WHERE X is Personne, X nom AA, X prenom AB, X travaille AC?, AC nom AD')
+                              'Any X,AA,AB,AC,AD ORDERBY AA WHERE X is_instance_of Personne, X nom AA, X prenom AB, X travaille AC?, AC nom AD')
             # testing relation with cardinality > 1
             peschema.subjrels['travaille'].rdef(peschema, seschema).cardinality = '**'
             self.assertEqual(Personne.fetch_rql(user),
-                              'Any X,AA,AB ORDERBY AA WHERE X is Personne, X nom AA, X prenom AB')
+                              'Any X,AA,AB ORDERBY AA WHERE X is_instance_of Personne, X nom AA, X prenom AB')
             # XXX test unauthorized attribute
         finally:
             # fetch_attrs restored by generic tearDown
@@ -301,7 +307,7 @@ class EntityTC(CubicWebTC):
         rql = user.cw_unrelated_rql('use_email', 'EmailAddress', 'subject')[0]
         self.assertEqual(rql, 'Any O,AA,AB,AC ORDERBY AC DESC '
                          'WHERE NOT A use_email O, S eid %(x)s, '
-                         'O is EmailAddress, O address AA, O alias AB, O modification_date AC')
+                         'O is_instance_of EmailAddress, O address AA, O alias AB, O modification_date AC')
 
     def test_unrelated_rql_security_1_user(self):
         req = self.request()
@@ -311,7 +317,7 @@ class EntityTC(CubicWebTC):
         rql = user.cw_unrelated_rql('use_email', 'EmailAddress', 'subject')[0]
         self.assertEqual(rql, 'Any O,AA,AB,AC ORDERBY AC DESC '
                          'WHERE NOT A use_email O, S eid %(x)s, '
-                         'O is EmailAddress, O address AA, O alias AB, O modification_date AC')
+                         'O is_instance_of EmailAddress, O address AA, O alias AB, O modification_date AC')
         user = self.execute('Any X WHERE X login "admin"').get_entity(0, 0)
         rql = user.cw_unrelated_rql('use_email', 'EmailAddress', 'subject')[0]
         self.assertEqual(rql, 'Any O,AA,AB,AC ORDERBY AC DESC '
@@ -332,7 +338,7 @@ class EntityTC(CubicWebTC):
         email = self.execute('INSERT EmailAddress X: X address "hop"').get_entity(0, 0)
         rql = email.cw_unrelated_rql('use_email', 'CWUser', 'object')[0]
         self.assertEqual(rql, 'Any S,AA,AB,AC,AD ORDERBY AA '
-                         'WHERE NOT S use_email O, O eid %(x)s, S is CWUser, '
+                         'WHERE NOT S use_email O, O eid %(x)s, S is_instance_of CWUser, '
                          'S login AA, S firstname AB, S surname AC, S modification_date AD')
         self.login('anon')
         rperms = self.schema['EmailAddress'].permissions['read']
@@ -366,7 +372,7 @@ class EntityTC(CubicWebTC):
         rql = person.cw_unrelated_rql('connait', 'Personne', 'subject')[0]
         self.assertEqual(
             rql, 'Any O,AA,AB,AC ORDERBY AC DESC WHERE '
-            'O is Personne, O nom AA, O prenom AB, O modification_date AC')
+            'O is_instance_of Personne, O nom AA, O prenom AB, O modification_date AC')
 
     def test_unrelated_rql_constraints_creation_object(self):
         person = self.vreg['etypes'].etype_class('Personne')(self.request())
@@ -386,7 +392,7 @@ class EntityTC(CubicWebTC):
             person = self.vreg['etypes'].etype_class('Personne')(self.request())
             rql = person.cw_unrelated_rql('connait', 'Personne', 'subject')[0]
         self.assertEqual(rql, 'Any O,AA,AB,AC ORDERBY AC DESC WHERE '
-                         'O is Personne, O nom AA, O prenom AB, '
+                         'O is_instance_of Personne, O nom AA, O prenom AB, '
                          'O modification_date AC')
 
     def test_unrelated_rql_constraints_edition_subject(self):
@@ -429,7 +435,7 @@ class EntityTC(CubicWebTC):
         rql, args = person.cw_unrelated_rql('actionnaire', 'Societe', 'subject',
                                             lt_infos=lt_infos)
         self.assertEqual(u'Any O ORDERBY O WHERE NOT A actionnaire O, '
-                         u'O is Societe, NOT EXISTS(O eid %(O)s), '
+                         u'O is_instance_of Societe, NOT EXISTS(O eid %(O)s), '
                          u'A is Personne', rql)
         self.assertEqual({'O': soc.eid}, args)
 
@@ -442,7 +448,7 @@ class EntityTC(CubicWebTC):
         rql, args = soc.cw_unrelated_rql('actionnaire', 'Personne', 'object',
                                          lt_infos=lt_infos)
         self.assertEqual(u'Any S ORDERBY S WHERE NOT S actionnaire A, '
-                         u'S is Personne, NOT EXISTS(S eid %(S)s), '
+                         u'S is_instance_of Personne, NOT EXISTS(S eid %(S)s), '
                          u'A is Societe', rql)
         self.assertEqual({'S': person.eid}, args)
 
@@ -455,7 +461,7 @@ class EntityTC(CubicWebTC):
         rql, args = soc.cw_unrelated_rql('dirige', 'Personne', 'object',
                                          lt_infos=lt_infos)
         self.assertEqual(u'Any S ORDERBY S WHERE NOT S dirige A, '
-                         u'S is Personne, EXISTS(S eid %(S)s), '
+                         u'S is_instance_of Personne, EXISTS(S eid %(S)s), '
                          u'A is Societe', rql)
         self.assertEqual({'S': person.eid}, args)
 
@@ -465,7 +471,7 @@ class EntityTC(CubicWebTC):
         self.vreg['etypes'].etype_class('Personne').fetch_attrs = ()
         soc = req.create_entity('Societe', nom=u'logilab')
         rql, args = person.cw_unrelated_rql('associe', 'Personne', 'subject')
-        self.assertEqual(u'Any O ORDERBY O WHERE O is Personne', rql)
+        self.assertEqual(u'Any O ORDERBY O WHERE O is_instance_of Personne', rql)
         self.assertEqual({}, args)
 
     def test_unrelated_rql_s_linkto_s_unused_info(self):
@@ -476,7 +482,7 @@ class EntityTC(CubicWebTC):
         lt_infos = {('dirige', 'subject'): [other_p.eid]}
         rql, args = person.cw_unrelated_rql('associe', 'Personne', 'subject',
                                             lt_infos=lt_infos)
-        self.assertEqual(u'Any O ORDERBY O WHERE O is Personne', rql)
+        self.assertEqual(u'Any O ORDERBY O WHERE O is_instance_of Personne', rql)
 
     def test_unrelated_base(self):
         req = self.request()
@@ -545,7 +551,7 @@ class EntityTC(CubicWebTC):
         e = self.request().create_entity('Card', title=u'rest test', content=u'du :eid:`1:*ReST*`',
                                          content_format=u'text/rest')
         self.assertEqual(e.printable_value('content'),
-                         '<p>du <a class="reference" href="http://testing.fr/cubicweb/cwsource/system">*ReST*</a></p>')
+                         '<p>du <a class="reference" href="http://testing.fr/cubicweb/cwsource/system">*ReST*</a></p>\n')
         e.cw_attr_cache['content'] = 'du <em>html</em> <ref rql="CWUser X">users</ref>'
         e.cw_attr_cache['content_format'] = 'text/html'
         self.assertEqual(e.printable_value('content'),
@@ -553,7 +559,7 @@ class EntityTC(CubicWebTC):
         e.cw_attr_cache['content'] = 'du *texte*'
         e.cw_attr_cache['content_format'] = 'text/plain'
         self.assertEqual(e.printable_value('content'),
-                          '<p>\ndu *texte*<br/></p>')
+                          '<p>\ndu *texte*<br/>\n</p>')
         e.cw_attr_cache['title'] = 'zou'
         e.cw_attr_cache['content'] = '''\
 a title
@@ -584,21 +590,24 @@ du :eid:`1:*ReST*`'''
             if tuple(int(i) for i in pygments.__version__.split('.')[:2]) >= (1, 3):
                 self.assertEqual(e.printable_value('data'),
                                   '''<div class="highlight"><pre><span class="k">lambda</span> <span class="n">x</span><span class="p">:</span> <span class="mi">1</span>
-</pre></div>''')
+</pre></div>
+''')
             else:
                 self.assertEqual(e.printable_value('data'),
                                   '''<div class="highlight"><pre><span class="k">lambda</span> <span class="n">x</span><span class="p">:</span> <span class="mf">1</span>
-</pre></div>''')
+</pre></div>
+''')
         else:
             self.assertEqual(e.printable_value('data'),
                               '''<pre class="python">
 <span style="color: #C00000;">lambda</span> <span style="color: #000000;">x</span><span style="color: #0000C0;">:</span> <span style="color: #0080C0;">1</span>
-</pre>''')
+</pre>
+''')
 
         e = req.create_entity('File', data=Binary('*héhéhé*'), data_format=u'text/rest',
                             data_encoding=u'utf-8', data_name=u'toto.txt')
         self.assertEqual(e.printable_value('data'),
-                          u'<p><em>héhéhé</em></p>')
+                          u'<p><em>héhéhé</em></p>\n')
 
     def test_printable_value_bad_html(self):
         """make sure we don't crash if we try to render invalid XHTML strings"""
@@ -751,7 +760,7 @@ du :eid:`1:*ReST*`'''
         self.assertEqual(card.absolute_url(),
                           'http://testing.fr/cubicweb/%s' % card.eid)
 
-    def test_create_entity(self):
+    def test_create_and_compare_entity(self):
         req = self.request()
         p1 = req.create_entity('Personne', nom=u'fayolle', prenom=u'alexandre')
         p2 = req.create_entity('Personne', nom=u'campeas', prenom=u'aurelien')
@@ -765,6 +774,15 @@ du :eid:`1:*ReST*`'''
         self.assertEqual(sorted([c.nom for c in p.evaluee]), ['campeas', 'fayolle'])
         self.assertEqual([c.type for c in p.reverse_ecrit_par], ['z'])
 
+        req = self.request()
+        auc = req.execute('Personne P WHERE P prenom "aurelien"').get_entity(0,0)
+        persons = set()
+        persons.add(p1)
+        persons.add(p2)
+        persons.add(auc)
+        self.assertEqual(2, len(persons))
+        self.assertNotEqual(p1, p2)
+        self.assertEqual(p2, auc)
 
 
 if __name__ == '__main__':
