@@ -29,6 +29,7 @@ from warnings import warn
 
 from logilab.mtconverter import xml_escape
 from logilab.common.graph import escape
+from logilab.common.deprecation import class_deprecated
 
 from cubicweb import Unauthorized
 from cubicweb.predicates import (has_related_entities, one_line_rset,
@@ -436,19 +437,14 @@ class WorkflowGraphView(DotGraphView):
 
 
 class TmpPngView(TmpFileViewMixin, EntityView):
+    __metaclass__ = class_deprecated
+    __deprecation_warning__ = '[3.18] %(cls)s is deprecated'
     __regid__ = 'tmppng'
     __select__ = match_form_params('tmpfile')
     content_type = 'image/png'
     binary = True
 
     def cell_call(self, row=0, col=0):
-        key = self._cw.form['tmpfile']
-        if key not in self._cw.session.data:
-            # the temp file is gone and there's nothing
-            # we can do about it
-            # we should probably write it to some well
-            # behaved place and serve it
-            return
-        tmpfile = self._cw.session.data.pop(key)
+        tmpfile = self._cw.session.data[self._cw.form['tmpfile']]
         self.w(open(tmpfile, 'rb').read())
         os.unlink(tmpfile)
